@@ -40,16 +40,8 @@ logging.basicConfig(
 def resolve_ndsserver(ndsserver=None):
     if not ndsserver:
         ndsserver = os.getenv('NDSSERVER', const.NDSSERVER).split(',')[0]
-    hostport = ndsserver.split(':')
-    host = hostport[0]
-    try:
-        port = int(hostport[1])
-    except IndexError:
-        port = 31200
-    return ':'.join((host, str(port)))
-
-
-NDSSERVER = resolve_ndsserver()
+    ndsserver = ndsserver.lower()
+    return const.NDSSERVER_ALIAS_MAP.get(ndsserver, ndsserver)
 
 
 def full_version():
@@ -206,8 +198,8 @@ parser.add_argument('--title', '--window-title', dest='window_title', metavar='T
                     help="application window title")
 parser.add_argument('-bw', '--black-on-white', action='store_true',
                     help="black-on-white plots, instead of white-on-black")
-parser.add_argument('--nds', metavar='HOST[:PORT]', default=NDSSERVER,
-                    help=f"NDS server [{NDSSERVER}]")
+parser.add_argument('--nds', metavar='HOST[:PORT]',
+                    help=f"NDS server [{const.NDSSERVER}]")
 parser.add_argument('--gen-template', action='store_true',
                     help="generate YAML layout, dump to stdout, and exit")
 parser.add_argument('--file',
