@@ -12,7 +12,7 @@ except ImportError:
     from PyQt5 import QtCore
     from PyQt5.QtGui import QFont, QColor, QPen
 
-from gpstime import gpsnow
+from gpstime import gpstime, gpsnow
 
 from . import util
 from . import const
@@ -67,6 +67,37 @@ def hold_over_nan(y):
 class TimeStringAxis(pg.AxisItem):
     def __init__(self, orientation='bottom', **kwargs):
         super().__init__(orientation, **kwargs)
+        self.t0 = 0
+        self.tick_func = self.t_to_relative
+
+    def t_to_relative(self, t):
+        return str(util.TDStr(t))
+
+    def t_to_gps(self, t):
+        return t + self.t0
+
+    def t_to_utc(self, t):
+        gps = gpstime.fromgps(t + self.t0)
+        return gps.strftime(const.TICK_DATE_FMT)
+
+    def t_to_local(self, t):
+        gps = gpstime.fromgps(t + self.t0)
+        local = gps.astimezone()
+        return local.strftime(const.TICK_DATE_FMT)
+
+    def setTickStringsMode(self, mode):
+        func_map = {
+            'relative': self.t_to_relative,
+            'gps': self.t_to_gps,
+            'utc': self.t_to_utc,
+            'local': self.t_to_local,
+        }
+        self.tick_func = func_map[mode]
+        # this is needed to clear/update the ticks on change:
+        self.picture = None
+        self.update()
+
+    ######
 
     def tickSpacing(self, minVal, maxVal, size):
         span = abs(maxVal - minVal)
@@ -79,8 +110,7 @@ class TimeStringAxis(pg.AxisItem):
         ]
 
     def tickStrings(self, values, scale, spacing):
-        return [str(util.TDStr(t)) for t in values]
-
+        return [self.tick_func(t) for t in values]
 
 ##################################################
 
@@ -234,6 +264,7 @@ class NDScopePlot(PlotItem):
         time for t=0.
 
         """
+        self.axes['bottom']['item'].t0 = t0
         self._set_t_limits(t0)
 
         ctype_changed = False
